@@ -627,6 +627,11 @@ describe "PostgreSQL support" do
     @db.sqls.must_equal ['CREATE INDEX "posts_user_id_index" ON "posts" USING btree ("user_id" int4_ops)']
   end
 
+  it "should support add_index :only option" do
+    @db.alter_table(:posts){add_index(:user_id, :only=> true)}
+    @db.sqls.must_equal ['CREATE INDEX "posts_user_id_index" ON ONLY "posts" ("user_id")']
+  end
+
   it 'should quote NaN' do
     nan = 0.0/0.0
     @db[:test5].insert_sql(:value => nan).must_equal %q{INSERT INTO "test5" ("value") VALUES ('NaN')}
@@ -886,6 +891,16 @@ describe "PostgreSQL support" do
     ]
   end
 
+  it "should default generated columns to STORED" do
+    @db.create_table(:t){Integer :c, :generated_always_as=>Sequel[:t] + 1}
+    @db.sqls.must_equal ['CREATE TABLE "t" ("c" integer GENERATED ALWAYS AS (("t" + 1)) STORED)']
+  end
+
+  it "should create VIRTUAL generated columns if given :virtual option" do
+    @db.create_table(:t){Integer :c, :generated_always_as=>Sequel[:t] + 1, :virtual=>true}
+    @db.sqls.must_equal ['CREATE TABLE "t" ("c" integer GENERATED ALWAYS AS (("t" + 1)) VIRTUAL)']
+  end
+
   it "should not support converting serial columns to identity on PostgreSQL <10.2" do
     def @db.server_version; 100000; end
     proc{@db.convert_serial_to_identity(:table)}.must_raise Sequel::Error
